pub struct WriterLock { /* private fields */ }Expand description
Optional cooperating-writer lock helper.
The journal file format does not define a lock protocol. Callers that want SDK-to-SDK writer exclusion can acquire this helper before opening a writer and release it after closing that writer.
Implementations