Module offset_array
journal_
core
0.8.0
Module offset_
array
Module Items
Structs
Enums
In journal_
core::
file
journal_core
::
file
Module
offset_
array
Structs

Cursor
A cursor pointing to a specific position within an offset array chain
Inlined
Cursor
List
A linked list of offset arrays
Node
A reference to a single array of offsets in the journal file
Enums

Direction