pub struct File { /* private fields */ }Implementations
Sourceimpl File
impl File
pub fn path(&self) -> &str
pub fn origin(&self) -> &Origin
pub fn status(&self) -> &Status
pub fn from_path(path: &Path) -> Option<File>
pub fn from_raw_path(path: &Path) -> Option<File>
pub fn from_str(path: &str) -> Option<File>
pub fn dir(&self) -> Result<&str, RepositoryError>
Sourcepub fn is_journal_file(path: &str) -> bool
pub fn is_journal_file(path: &str) -> bool
Check if a path looks like a journal file
Sourcepub fn is_active(&self) -> bool
pub fn is_active(&self) -> bool
Check if this is an active journal file that’s currently being written to
Sourcepub fn is_archived(&self) -> bool
pub fn is_archived(&self) -> bool
Check if this is an archived journal file
Sourcepub fn is_disposed(&self) -> bool
pub fn is_disposed(&self) -> bool
Check if this is a corrupted/disposed journal file
pub fn is_remote(&self) -> bool
Sourcepub fn remote_host(&self) -> Option<&str>
pub fn remote_host(&self) -> Option<&str>
Get the remote host if this is a remote journal