Module offset_array

Module offset_array 

Structs

Cursor
A cursor pointing to a specific position within an offset array chain
InlinedCursor
List
A linked list of offset arrays
Node
A reference to a single array of offsets in the journal file

Enums

Direction