List

Struct List 

pub struct List { /* private fields */ }
A linked list of offset arrays

Implementations

Source

impl List

pub fn new(head_offset: NonZeroU64, total_items: NonZeroUsize) -> Self

Create a new list from head offset and total items

pub fn head<M: MemoryMap>(&self, journal_file: &JournalFile<M>) -> Result<Node>

Get the head array of this chain

pub fn tail<M: MemoryMap>(&self, journal_file: &JournalFile<M>) -> Result<Node>

Get the tail array of this list by traversing from head to tail

pub fn cursor_head(self) -> Cursor

Get a cursor at the first position in the chain

pub fn cursor_tail<M: MemoryMap>( self, journal_file: &JournalFile<M>, ) -> Result<Cursor>

Get a cursor at the last position in the chain

pub fn directed_partition_point<M, F>( self, journal_file: &JournalFile<M>, predicate: F, direction: Direction, ) -> Result<Option<Cursor>>
where M: MemoryMap, F: Fn(NonZeroU64) -> Result<bool>,

pub fn collect_offsets<M: MemoryMap>( &self, journal_file: &JournalFile<M>, offsets: &mut Vec<NonZeroU64>, ) -> Result<()>

Collect all offsets in the entire list into the given vector