Node

Struct Node 

pub struct Node { /* private fields */ }
A reference to a single array of offsets in the journal file

Implementations

Source

impl Node

pub fn offset(&self) -> NonZeroU64

Get the offset of this array in the file

pub fn capacity(&self) -> NonZeroUsize

Get the maximum number of items this array can hold

pub fn len(&self) -> NonZeroUsize

Get the number of items available in this array

pub fn has_next(&self) -> bool

Check if this array has a next array in the chain

pub fn next<M: MemoryMap>( &self, journal_file: &JournalFile<M>, ) -> Result<Option<Self>>

Get the next array in the chain, if any

pub fn get<M: MemoryMap>( &self, journal_file: &JournalFile<M>, index: usize, ) -> Result<Option<NonZeroU64>>

Get an item at the specified index

pub fn partition_point<M, F>( &self, journal_file: &JournalFile<M>, left: usize, right: usize, predicate: F, ) -> Result<usize>
where M: MemoryMap, F: Fn(NonZeroU64) -> Result<bool>,

Returns the first index where the predicate returns false, or array length if the predicate is true for all elements

pub fn directed_partition_point<M, F>( &self, journal_file: &JournalFile<M>, left: usize, right: usize, predicate: F, direction: Direction, ) -> Result<Option<usize>>
where M: MemoryMap, F: Fn(NonZeroU64) -> Result<bool>,

Find the forward or backward (depending on direction) position that matches the predicate.